@@ -20,8 +20,7 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-from manager import *
-from .manager import *
+from pipcontrol import *
 
 __all__ = [
     "install",
